import type { ErrorMessage } from "$lib/api";
import { remove, EntityTypes, type EntityName } from "$lib/entities";
import type { RequestHandler } from "./$types";

function isErrorMessage(value: any): value is ErrorMessage {
  return value && typeof value.message === 'string';
}

export const DELETE: RequestHandler = async ({ request, cookies, params }): Promise<Response> => {
  const session = cookies.get('session')
  const { entity } = params;

  if (!session) {
    throw new Response(JSON.stringify("no cookies"), { status: 401 })
  }

  if (!(entity in EntityTypes)) {
    return new Response(JSON.stringify("Invalid entity"), { status: 400 });
  }

  const { id }: { id: number } = await request.json();
  const result = await remove(entity as EntityName, id, session);
  if (isErrorMessage(result)) {
    return new Response(JSON.stringify(result), { status: 500 })
  }
  return new Response(JSON.stringify(result), { status: 200 })
}
